============
repositories
============

.. automodule:: advanced_alchemy.repository
    :members: SQLAlchemyAsyncRepository SQLAlchemyAsyncSlugRepository SQLAlchemyAsyncQueryRepository SQLAlchemySyncRepository SQLAlchemySyncSlugRepository SQLAlchemySyncQueryRepository
    :noindex: Empty EmptyType ErrorMessages NotFoundError
